@@ -5,8 +5,7 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_GLOBAL_SHORTCUTS_PLUGIN_H
-#define PLUGINS_GLOBAL_SHORTCUTS_PLUGIN_H
+#pragma once
 
 #include <Plugin.h>
 class KActionCollection;
@@ -15,10 +14,9 @@ class QAction;
 class GlobalShortcutsPlugin : public Plugin
 {
     Q_OBJECT
-    // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.globalshortcutsplugin")
 
 public:
-    explicit GlobalShortcutsPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit GlobalShortcutsPlugin(QObject *parent);
     ~GlobalShortcutsPlugin() override;
 
     bool init(QHash<QString, QObject *> &modules) override;
@@ -39,5 +37,3 @@ private:
     QStringList m_activitiesList;
     KActionCollection *m_actionCollection;
 };
-
-#endif // PLUGINS_GLOBAL_SHORTCUTS_PLUGIN_H
